This test contains the example sequence that is used as an illustration in the `README.md` file of the `crest4` repository.

The sequence is taken from:

https://www.ncbi.nlm.nih.gov/nuccore/MW274389.1

And the submitted classification is:

* Bacteria; Cyanobacteria; Synechococcales; environmental samples.